==> sirdeploy-1.0.2.tgz: package/readme.md <==
# Deploy Server

[Site](https://shantanubombatkar.shodkk.com) |
[Contributing](https://github.com/shaantanu9/DeployHerokuServer) |
[Code of Conduct](https://code-of-conduct.openjsf.org) |
[Twitter](https://twitter.com/ShantanuMali9) |
[Chat](https://gitter.im/shaantanu9)

### Bored Creating Server and Deploying it on Heroku 
The [DeployServer](https://github.com/shaantanu9/DeployHerokuServer) is a npm Package that help you do all this deployement in single click.

## $ npm i --location=global deployserver 
#### It is CLI Base so need to install Globally

#
### How to Use in Terminal:
```shell
Steps to Follow:
1. Install DeployServer Globally: $ npm i --location=global deployserver
2. Create a Folder with Any name: $ mkdir newProject.
3. create db.json file with respected data.
4. deployserver heroku-fakeserver newProject

```

## Go Through the Already Build Templates

**configure-tailwind** is released under the [MIT license](https://github.com/shaantanu9/configure-tailwind/blob/main/LICENSE) & supports modern environments.<br>
#### Please Star the [Repo](https://github.com/shaantanu9/configure-tailwind) on GitHub and Share with Other Fellow Developers

## Installation

Using npm:
```shell
$ npm i -g configure-tailwind 
// it is CLI Base so need to install Globally

$ npm i configure-tailwind
```
Note: add `--save` if you are using npm < 5.0.0



Bore Configuring Tailwind for React App, or any other Framework Try this Package Once.

## Why deployServer Package?

Programming is all About simplifying and Automating Stuff<br>

### Then Why Build Same BoilerPlate Again and Again 


Use this Package and (getAwayFromThePain) create BoilerPlate 
 * Get Read of Wrting and Creating Same Thing
 * Directly Start Working on the real Logic
 * Reduce time of Development by atleast 10% 

### Please Contribute Models and Controllers

#### Become a [Open Source Contributer](https://github.com/shaantanu9/DeployHerokuServer)
We **DeployServer** wants to help Each and Every Programmer Writing real Logical code, without **wasting time** this simple thing.

So We are Here With this Package to help you to write real Logical code, without wasting time.

### How can You Support and Help others?


 * Go the [Github Repo](https://github.com/shaantanu9/DeployHerokuServer)
 * Fork that Repo 
 * Clone and Download it and Add the File in given manner. 
 * Add the Changes and push to your account.
 * Upload in your Repo => Pull Request and Done
 
 
 ## Licence
 MIT
 
 #### I love to work on ***All Open Source Projects***
 #### **Please Please Contact Me** [Linkedin](https://www.linkedin.com/in/shantanu-bombatkar) [Twitter](https://twitter.com/ShantanuMali9)

==> sirdeploy-1.0.4.tgz: package/readme.md <==
# Deploy Server

[Site](https://shantanubombatkar.shodkk.com) |
[Contributing](https://github.com/shaantanu9/DeployHerokuServer) |
[Code of Conduct](https://code-of-conduct.openjsf.org) |
[Twitter](https://twitter.com/ShantanuMali9) |
[Chat](https://gitter.im/shaantanu9)

### Bored Creating Server and Deploying it on Heroku 
The [DeployServer](https://github.com/shaantanu9/DeployHerokuServer) is a npm Package that help you do all this deployement in single click.

## $ npm i --location=global deployserver 
#### It is CLI Base so need to install Globally

#
### How to Use in Terminal:
```shell
Steps to Follow:
1. Install DeployServer Globally: $ npm i --location=global deployserver
2. Create a Folder with Any name: $ mkdir newProject.
3. create db.json file with respected data.
4. deployserver heroku-fakeserver newProject

```

## Go Through the Already Build Templates

**sirdeploy** is released under the [MIT license](https://github.com/shaantanu9/DeployHerokuServer/blob/main/LICENSE) & supports modern environments.<br>
#### Please Star the [Repo](https://github.com/shaantanu9/DeployHerokuServer) on GitHub and Share with Other Fellow Developers

## Installation

Using npm:
```shell
$ npm i --location=global deployserver
// it is CLI Base so need to install Globally

$ mkdir newProject
// File that contain the db.json data

$ deployserver heroku-fakeserver newProject
// Last Command that Do Everything for you
```
Note: add `--save` if you are using npm < 5.0.0



Bore Create FakeBackend for React App, or any other Framework Try this Package Once.

## Why deployServer Package?

Programming is all About simplifying and Automating Stuff<br>

### Then Why Build Same BoilerPlate Again and Again 


Use this Package and (getAwayFromThePain) create BoilerPlate 
 * Get Read of Wrting and Creating Same Thing
 * Directly Start Working on the real Logic
 * Reduce time of Development by atleast 10% 

### Please Contribute Models and Controllers

#### Become a [Open Source Contributer](https://github.com/shaantanu9/DeployHerokuServer)
We **DeployServer** wants to help Each and Every Programmer Writing real Logical code, without **wasting time** this simple thing.

So We are Here With this Package to help you to write real Logical code, without wasting time.

### How can You Support and Help others?


 * Go the [Github Repo](https://github.com/shaantanu9/DeployHerokuServer)
 * Fork that Repo 
 * Clone and Download it and Add the File in given manner. 
 * Add the Changes and push to your account.
 * Upload in your Repo => Pull Request and Done
 
 
 ## Licence
 MIT
 
 #### I love to work on ***All Open Source Projects***
 #### **Please Please Contact Me** [Linkedin](https://www.linkedin.com/in/shantanu-bombatkar) [Twitter](https://twitter.com/ShantanuMali9)
